using System;
using System.Windows.Forms;
using System.ComponentModel;
using WeifenLuo.WinFormsUI;
using PluginCore;

namespace DemoPlugin
{
	public class PluginMain : IPlugin
	{
		private string pluginName = "DemoPlugin";
		private string pluginGuid = "E876BA92-577C-41C5-8E27-18AD57290DDD";
		private string pluginAuth = "Philippe Elsass";
		private string pluginHelp = "http://flashdevelop.org/community/";
		private string pluginDesc = "A demo plugin";
		private EventType eventMask = 0;
		private IPluginHost pluginHost;
		private IMainForm mainForm;
		private DockContent pluginPanel;
		private PluginUI pluginUI;

		#region RequiredPluginVariables

		public string Name
		{
			get { return this.pluginName; }
		}

		public string Guid
		{
			get { return this.pluginGuid; }
		}

		public string Author
		{
			get { return this.pluginAuth; }
		}

		public string Description
		{
			get { return this.pluginDesc; }
		}

		public string Help
		{
			get { return this.pluginHelp; }
		}

		public EventType EventMask
		{
			get { return this.eventMask; }
		}

		[Browsable(false)]
		public IPluginHost Host
		{
			get { return this.pluginHost; }
			set	{ this.pluginHost = value; }
		}

		[Browsable(false)]
		public DockContent Panel
		{
			get { return this.pluginPanel; }
		}
		
		#endregion

		#region RequiredPluginMethods

		/**
		* Initializes the plugin
		*/
		public void Initialize()
		{
			this.mainForm = this.pluginHost.MainForm;
			this.pluginUI = new PluginUI(this);
			System.Drawing.Image image = mainForm.GetSystemImage(19);
			/**
			*  Create panel
			*/
			this.pluginUI.Tag = "Demo";
			this.pluginUI.Text = "Demo";
			this.pluginPanel = mainForm.CreateDockingPanel(this.pluginUI, 
				this.pluginGuid, image, DockState.DockLeftAutoHide);
			/**
			*  Create menu item
			*/
			CommandBarMenu ViewMenu = mainForm.GetCBMenu("ViewMenu");
			ViewMenu.Items.AddButton(image, "Demo Panel", 
			                         new EventHandler(this.OpenPanel));
		}

		/**
		* Disposes the plugin
		*/
		public void Dispose()
		{
			// free system ressources
		}

		/**
		* Handles the incoming events
		* Receives only events in EventMask
		*/
		public void HandleEvent(object sender, NotifyEvent e)
		{
			// handle events
		}

		/**
		* Opens the plugin panel again if closed
		*/
		public void OpenPanel(object sender, System.EventArgs e)
		{
			// show pluginPanel
			this.pluginPanel.Show();
		}

		#endregion

	}

}
